@@ -4,6 +4,7 @@ function(keys,r.mat,correct=TRUE,digits=2) { #function to extract clusters accor
 				#find the correlation matrix of scales made up of items defined in a keys matrix (e.g., extracted by factor2cluster) 
                 #takes as input the keys matrix as well as a correlation matrix of all the items
  tol=sqrt(.Machine$double.eps)    #machine accuracy
+ cl <- match.call()
  if(!is.matrix(keys)) keys <- as.matrix(keys)  #keys are sometimes a data frame - must be a matrix
  r.mat[is.na(r.mat)] <- -9999999    #changes missing values to obviously incorrect values
  covar <- t(keys) %*% r.mat %*% keys    #matrix algebra is our friend
@@ -20,11 +21,11 @@ function(keys,r.mat,correct=TRUE,digits=2) { #function to extract clusters accor
  colnames(cluster.correl) <- colnames(keys)
  rownames(cluster.correl) <- colnames(keys)
  if (correct) {cluster.corrected <- correct.cor(cluster.correl,t(key.alpha))
- result <- list(cor=round(cluster.correl,digits),sd=round(sqrt(var),digits),corrected= round(cluster.corrected,digits),alpha=round(key.alpha,digits),av.r = round(key.av.r,2),size=key.var)
+ result <- list(cor=round(cluster.correl,digits),sd=round(sqrt(var),digits),corrected= round(cluster.corrected,digits),alpha=round(key.alpha,digits),av.r = round(key.av.r,2),size=key.var,Call=cl)
  }  #correct for attenuation
  else {
-result <- list(cor=round(cluster.correl,digits),sd=round(sqrt(var),digits),alpha=round(key.alpha,digits),av.r = round(key.av.r,2),size=key.var)}
- class(result) <- "psych"
+result <- list(cor=round(cluster.correl,digits),sd=round(sqrt(var),digits),alpha=round(key.alpha,digits),av.r = round(key.av.r,2),size=key.var,Call=cl)}
+ class(result) <- c ("psych", "cluster.cor")
  return(result)}
 #revised August 21, 2007 to add a smidgen to 1.0 in the looking for NAs.
 #revised June 14, 2008 to add average.r
